@@ -5,5 +5,5 @@ from entity_emailer.views import EmailView
 
 urlpatterns = patterns(
     '',
-    url(r'^([0-9]+)/$', EmailView.as_view(), name='entity_emailer.email'),
+    url(r'^([0-9a-z\-]+)/$', EmailView.as_view(), name='entity_emailer.email'),
 )
